# isdc-client
[![Build Status](https://travis-ci.org/volodymyrss/isdc-client.svg?branch=master)](https://travis-ci.org/volodymyrss/isdc-client)
[![codebeat badge](https://codebeat.co/badges/be1fafc7-ebdc-4fdd-8f60-18b1630c85bc)](https://codebeat.co/projects/github-com-volodymyrss-isdc-client-master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/940dc23fa91942e8b2ed32f4d5d3287d)](https://www.codacy.com/app/vladimir.savchenko/isdc-client?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=volodymyrss/isdc-client&amp;utm_campaign=Badge_Grade)
[![DOI](https://zenodo.org/badge/72007541.svg)](https://zenodo.org/badge/latestdoi/72007541)
